@@ -1,10 +1,9 @@
-__all__ = [
-    '_FeatureInfo'
-]
+__all__ = ["_FeatureInfo"]
+
 
 class _FeatureInfo:
     r"""Class for feature representation.
-    
+
     Date:
         2021
 
@@ -33,4 +32,4 @@ class _FeatureInfo:
         self.dtype = dtype
         self.values = values
         self.min = min_val
-        self.max = max_val
\ No newline at end of file
+        self.max = max_val
