@@ -1,9 +1,10 @@
 from unittest import TestCase
 from niaclass.feature_info import _FeatureInfo
 
+
 class FeatureInfoTestCase(TestCase):
     def test_init_works_fine(self):
-        vals = ['val1', 'val2', 'val3']
+        vals = ["val1", "val2", "val3"]
         f_info = _FeatureInfo(dtype=0, values=vals)
         self.assertEqual(f_info.dtype, 0)
         self.assertEqual(f_info.min, None)
@@ -14,4 +15,4 @@ class FeatureInfoTestCase(TestCase):
         self.assertEqual(f_info.dtype, 1)
         self.assertEqual(f_info.min, 0.0)
         self.assertEqual(f_info.max, 5.5)
-        self.assertEqual(f_info.values, None)
\ No newline at end of file
+        self.assertEqual(f_info.values, None)
